/* Memory management routines.
 *
 * Services is copyright (c) 1996-1997 Andy Church.
 *     E-mail: <achurch@dragonfire.net>   IRC: Alcan@EsperNet
 * This program is free but copyrighted software; see the file COPYING for
 * details.
 */

#include "services.h"

/*************************************************************************/
/*************************************************************************/

/* smalloc, scalloc, srealloc, sstrdup:
 *	Versions of the memory allocation functions which will cause the
 *	program to terminate with an "Out of memory" error if the memory
 *	cannot be allocated.  (Hence, the return value from these functions
 *	is never NULL.)
 */

void *smalloc(long size)
{
    void *buf;

    buf = malloc(size);
    if (!size)
	log("smalloc: Illegal attempt to allocate 0 bytes");
    if (!buf)
	raise(SIGUSR1);
    return buf;
}

void *scalloc(long elsize, long els)
{
    void *buf = calloc(elsize, els);
    if (!elsize || !els)
	log("scalloc: Illegal attempt to allocate 0 bytes");
    if (!buf)
	raise(SIGUSR1);
    return buf;
}

void *srealloc(void *oldptr, long newsize)
{
    void *buf = realloc(oldptr, newsize);
    if (!newsize)
	log("srealloc: Illegal attempt to allocate 0 bytes");
    if (!buf)
	raise(SIGUSR1);
    return buf;
}

char *sstrdup(const char *s)
{
    char *t = strdup(s);
    if (!t)
	raise(SIGUSR1);
    return t;
}

/*************************************************************************/
/*************************************************************************/

/* In the future: malloc() replacements that tell us if we're leaking and
 * maybe do sanity checks too... */

/*************************************************************************/
